Module util

Module util 

Helper modules that may be externally useful

Structs

AsyncSliceReader
Reads asynchronously from a slice of bytes, without attempting to acquire any more data if a read is attempted past the end of the slice.
AsyncSliceWriter
Writes asynchronously to a slice of bytes, without attempting to allocate more memory if a write is attempted past the end of the slice.