Helper modules that may be externally useful
Structs
- Async
Slice Reader - Reads asynchronously from a slice of bytes, without attempting to acquire any more data if a read is attempted past the end of the slice.
- Async
Slice Writer - Writes asynchronously to a slice of bytes, without attempting to allocate more memory if a write is attempted past the end of the slice.