pub struct AsyncSliceWriter<'b> { /* private fields */ }Expand description
Writes asynchronously to a slice of bytes, without attempting to allocate more memory if a write is attempted past the end of the slice.
Should a write be attempted past the end of the slice without any remaining space, an error of WriteZero will be returned.
Examples
use futures::{AsyncWriteExt, executor};
use diny_core::util::AsyncSliceWriter;
let send = [7u8; 5];
let mut buff = [0u8; 7];
let mut writer = AsyncSliceWriter::from(&mut buff[..]);
executor::block_on(writer.write(&send));
assert_eq!(send, writer.as_written());The written bytes can then be easily retrieved by using an AsyncSliceReader
use futures::AsyncReadExt;
use diny_core::util::AsyncSliceReader;
let mut recv = [0u8; 5];
let mut reader = AsyncSliceReader::from(&writer);
executor::block_on(reader.read(&mut recv));
assert_eq!(send, recv);Implementations
Sourceimpl<'b> AsyncSliceWriter<'b>
impl<'b> AsyncSliceWriter<'b>
Sourcepub fn new(buf: &'b mut [u8]) -> Self
pub fn new(buf: &'b mut [u8]) -> Self
Instantiates a new async reader that implements AsyncWrite over the provided slice.
Sourcepub fn bytes_written(&self) -> usize
pub fn bytes_written(&self) -> usize
Returns the number of bytes that have been written so far into the provided slice.
Sourcepub fn as_written(&self) -> &[u8] ⓘ
pub fn as_written(&self) -> &[u8] ⓘ
Returns a read-only slice of the data that has been written so far into the provided slice.